import { StateContainer } from 'react-state-connect';
import TransportLayer from './transport-layer';
import { Omit } from 'react-bind-component';
export interface RestState<T> {
    loading: boolean;
    /**
     * The endpoint is assumed to return a collection of entities.
     */
    response: T[];
}
export declare type PatchPayload<T extends {
    id: any;
}> = Pick<T, 'id'> & Partial<Omit<T, 'id'>>;
export interface IRestStore<T extends {
    id: any;
}> extends StateContainer<RestState<T>> {
    state: RestState<T>;
    /**
     * Create a new entity via a POST request.
     */
    post: (payload: Partial<Omit<T, 'id'>>) => Promise<T>;
    /**
     * Update an existing entity via a POST request.
     */
    patch: (payload: PatchPayload<T>) => Promise<T>;
}
export default class RestStore<T extends {
    id: any;
}> extends StateContainer<RestState<T>> implements IRestStore<T> {
    protected readonly api: string;
    protected readonly transportLayer: TransportLayer;
    constructor(api: string, transportLayer?: TransportLayer);
    post: (payload: Partial<Pick<T, Exclude<keyof T, "id">>>) => Promise<T>;
    patch: (payload: PatchPayload<T>) => Promise<T>;
    private fetchData;
    private onFetchData;
}
